#
# spec file for package accountsservice
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# allow to not build vala binding
%bcond_without vala

Name:           accountsservice
Version:        23.13.9
Release:        5.2
Summary:        D-Bus Service to Manipulate User Account Information
License:        GPL-3.0-or-later
Group:          System/Daemons
URL:            https://www.freedesktop.org/wiki/Software/AccountsService/
Source0:        https://www.freedesktop.org/software/accountsservice/%{name}-%{version}.tar.xz

# WARNING: do not remove/significantly change patch0 without updating the relevant patch in gdm too
# PATCH-FIX-OPENSUSE accountsservice-sysconfig.patch bnc#688071 vuntz@opensuse.org -- Read/write autologin configuration from sysconfig, like gdm (see gdm-sysconfig-settings.patch) WAS PATCH-FIX-OPENSUSE
Patch0:         accountsservice-sysconfig.patch
# PATCH-FIX-OPENSUSE accountsservice-filter-suse-accounts.patch vuntz@opensuse.org -- Filter out some system users that are specific to openSUSE
Patch1:         accountsservice-filter-suse-accounts.patch
# PATCH-FIX-OPENSUSE harden_accounts-daemon.service.patch jsegitz@suse.com -- For details please see https://en.opensuse.org/openSUSE:Security_Features#Systemd_hardening_effort
Patch2:         harden_accounts-daemon.service.patch

## SLE and Leap only patches start at 1000
# PATCH-FEATURE-SLE as-fate318433-prevent-same-account-multi-logins.patch fate#318433 cxiong@suse.com -- prevent multiple simultaneous login.
Patch1000:      as-fate318433-prevent-same-account-multi-logins.patch

BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-2.0) >= 2.63.5
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.63.5
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libsystemd) >= 186
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}

%description
The accountsservice server provides a set of D-Bus interfaces for
querying and manipulating user account information.

The implementation is based on the useradd, usermod and userdel
commands.

%package -n libaccountsservice0
Summary:        Client library for the user account information manipulation D-Bus service
# Clients do need the server to do something useful
Group:          System/Libraries
Requires:       %{name}

%description -n libaccountsservice0
The accountsservice server provides a set of D-Bus interfaces for
querying and manipulating user account information.

This package provides a client library for the service.

%package -n typelib-1_0-AccountsService-1_0
Summary:        Introspection bindings for the user account information manipulation service
Group:          System/Libraries

%description -n typelib-1_0-AccountsService-1_0
The accountsservice server provides a set of D-Bus interfaces for
querying and manipulating user account information.

This package provides the GObject Introspection bindings for the
client library.

%package devel
Summary:        Header files for the user account information manipulation service
Group:          Development/Libraries/C and C++
Requires:       libaccountsservice0 = %{version}
Requires:       typelib-1_0-AccountsService-1_0 = %{version}

%description devel
The accountsservice server provides a set of D-Bus interfaces for
querying and manipulating user account information.

%if %{with vala}
%package vala
Summary:        Vala bindings for accountsservice
Group:          Development/Libraries/C and C++
BuildRequires:  vala
Requires:       libaccountsservice0 = %{version}
Requires:       typelib-1_0-AccountsService-1_0 = %{version}

%description vala
The accountsservice server provides a set of D-Bus interfaces for
querying and manipulating user account information.

This package contains the Vala bindings for accountservice.
%endif

%lang_package

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1

# SLE and Leap patches start at 1000
%if 0%{?sle_version}
%patch -P 1000 -p1
%endif

%build
%meson \
	-Dintrospection=true \
	-Dgtk_doc=true \
%if %{with vala}
	-Dvapi=true \
%else
	-Dvapi=false \
%endif
	%{nil}
%meson_build

%install
%meson_install
%find_lang accounts-service

%pre
%service_add_pre accounts-daemon.service

%post
%service_add_post accounts-daemon.service

%preun
%service_del_preun accounts-daemon.service

%postun
%service_del_postun accounts-daemon.service

%post -n libaccountsservice0 -p /sbin/ldconfig
%postun -n libaccountsservice0 -p /sbin/ldconfig

%files
%license COPYING
%doc README.md
%{_unitdir}/accounts-daemon.service
%{_libexecdir}/accounts-daemon
%{_datadir}/dbus-1/system.d/org.freedesktop.Accounts.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.Accounts.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.Accounts.User.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.Accounts.service
%{_datadir}/polkit-1/actions/org.freedesktop.accounts.policy
# User templates
%dir %{_datadir}/accountsservice
%{_datadir}/accountsservice/user-templates
# Directories where the server stores user data
%dir %{_localstatedir}/lib/AccountsService
%dir %{_localstatedir}/lib/AccountsService/users
%dir %{_localstatedir}/lib/AccountsService/icons

%files -n libaccountsservice0
%{_libdir}/*.so.0*

%files -n typelib-1_0-AccountsService-1_0
%{_libdir}/girepository-1.0/AccountsService-1.0.typelib

%files devel
%doc AUTHORS TODO
%doc %{_datadir}/gtk-doc/html/lib%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/accountsservice.pc
%{_includedir}/accountsservice-1.0/
%{_datadir}/gir-1.0/AccountsService-1.0.gir

%if %{with vala}
%files vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/accountsservice.deps
%{_datadir}/vala/vapi/accountsservice.vapi
%endif

%files lang -f accounts-service.lang

%changelog
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Wed Aug  9 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Rebase as-fate318433-prevent-same-account-multi-logins.patch:
  (bsc#1213884).
* Wed Jul  5 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Rebase accountsservice-sysconfig.patch: (boo#1212675 boo#1212973).
- Remove accountsservice-assume-gdm.patch: Fixed by new rebasing
  of accountsservice-sysconfig.patch.
* Sat Jun 24 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add accountsservice-assume-gdm.patch: assume gdm when not being
  able to detect the used display manager. This is basically the
  same as was in place before we gained support for multiple DMs
  (boo#1212675).
* Wed Jun 21 2023 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 23.13.9:
  + daemon: Fix boot delay
  + user-manager:
  - Add cancellable to fetch user requests
  - Track non-existent users
- Changes from version 23.11.69:
  + Add lightdm autologin support
  + user:
  - Return an error when setting invalid language
  - Throw a warning for invalid locales
  - Support new LocalAccount property in cache file
  - Replace usermod -p with chpasswd -e
  + main:
  - Use new overridable USERDIR
  - Use new overridable ICONDIR
  - Use new overridable sysconfdir
  + daemon:
  - Add GetUsersLanguages() function
  - Don't crash if /etc/shadow doesn't exist
  + Updated translations.
- Rebase patches:
  + accountsservice-sysconfig.patch
  + accountsservice-filter-suse-accounts.patch
* Mon Aug  1 2022 Matthias Gerstner <matthias.gerstner@suse.com>
- Remove BuildIgnore for rpmlint-mini. This is a violation of the
  security policies applying to SUSE products as it circumvents the
  SUSE security team's control over what enters Factory and what
  not.
* Fri Jul 29 2022 Frederic Crozat <fcrozat@suse.com>
- Allow to build without vala support.
- Refresh harden_accounts-daemon.service.patch to not duplicate
  existing entries.
* Sat Apr 30 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 22.08.8
  + Handle missing admin groups when changing account types
  + Set PrivateTmp to false in the systemd service
  + Add function to set user password expiration policy
- Update to version 22.04.62
  + Updated Swedish translation
  + Updated Indonesian translation
  + Updated German translation
  + Updated slovak translation
  + Update Ukrainian translation
  + Updated Brazilian Portuguese translation
  + act-user: Use stronger hashing methods in make_crypted() if available.
  + act-user-manager: Watch for the daemon going away and coming back
  + user-manager: Update users tables on username changes
  + user: Translate property x-session property name to match the proxy one
  + Check GDBusMessage for INTERACTIVE_AUTHORIZATION flag
  + daemon: Fix error check in save_autologin()
  + Never delete the root filesystem when removing users
  + Remove user heuristics
  + user-classify: Add git to username blacklist
  + daemon: ensure cache files for system users are processed
  + daemon: Don't try to add admin users to non existing groups
  + Move D-Bus conf file to $(datadir)/dbus-1/system.d
- Rebased patches:
  + accountsservice-sysconfig.patch
  + accountsservice-filter-suse-accounts.patch
  + as-fate318433-prevent-same-account-multi-logins.patch
- Drop upstream fixed patches:
  + ac9b14f1c1bbca413987d0bbfeaad05804107e9a.patch
  + accountsservice-fix-gdm-crash.patch
  + accountsservice-read-root-user-cache.patch
  + accountsservice-wtmp-io-improvements.patch
* Tue Feb  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add ac9b14f1c1bbca413987d0bbfeaad05804107e9a.patch: Fix build
  with meson 0.61.0.
* Thu Nov  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Stop passing the no longer used nor recognized option
  user-heuristics=true to meson.
* Thu Aug 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update harden_accounts-daemon.service.patch: Do not proect home
  directories: the accounts daemon is used to create home
  directories upon user creation (boo#1189853).
* Mon Aug  9 2021 Yifan Jiang <yfjiang@suse.com>
- Spec layout cleaning up for harden_accounts-daemon.service.patch.
* Tue Jul 27 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_accounts-daemon.service.patch
* Tue Mar  2 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Add accountsservice-fix-gdm-crash.patch: Prevent crash of gdm
  upon service restart when automatic login is enabled
  (glfo#accountsservice/accountsservice#55).
* Tue Apr 14 2020 Yifan Jiang <yfjiang@suse.com>
- Apply as-fate318433-prevent-same-account-multi-logins.patch to Leap.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Sep 11 2019 Felix Zhang <fezhang@suse.com>
- Add accountsservice-wtmp-io-improvements.patch: Backports that
  improve wtmp io performance (boo#1139487).
- Refresh as-fate318433-prevent-same-account-multi-logins.patch.
* Wed May 29 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.6.55:
  + Memory leak fix.
  + Improved heuristics for identifying user session.
  + Export interfaces directory to pkgconfig.
  + Lock down state directory from prying eyes to be more friendly to
    accountsservice extensions that require privacy.
  + Misc fixes.
  + Updated translations.
- Drop accountsservice-upstream-fixes.patch: Fixed upstream.
- Refresh patches with refresh_patches osc service.
* Wed May  8 2019 xwang@suse.com
- Update accountsservice-read-root-user-cache.patch.
  upstream commit d8b77951
  (bsc#1114292 glfo#accountsservice/accountsservice#65).
* Wed Apr  3 2019 xwang@suse.com
- Drop upstream fixed patches:
  + accountsservice-lib-don-not-set-loaded-state-until-seat-fetched.patch
- Update patches:
  + accountsservice-read-root-user-cache.patch
  + accountsservice-sysconfig.patch
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Redo summaries without em dashes.
- Reduce %%systemd_requires to %%systemd_ordering:
  %%service_* can handle the absence.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 0.6.54:
  + Fix user state dirs.
- Changes from version 0.6.53:
  + Fix introspection.
- Changes from version 0.6.52:
  + Migrate to meson and gettext (instead of autogoo and intltool).
  + Add code of conduct.
  + Add new session and session type properties (to replace
    XSession).
  + Try to handle misbehaving logind a little better.
  + Misc mixes and code modernization.
  + Add new "Saved" property to say whether a cached user is stored
    on disk.
- Add accountsservice-upstream-fixes.patch: Add upstream bug fixes
  commits, fix build.
- Switch to meson build system, add meson BuildRequires and macros.
- Drop obsolete intltool, gnome-common, vala, xmlto and xsltproc
  BuildRequires: No longer needed.
- Replace gobject-introspection-devel with
  pkgconfig(gobject-introspection-1.0) and add pkgconfig(dbus-1):
  New depdendency.
- Disable the following patches that needs rebase:
  + accountsservice-sysconfig.patch.
  + accountsservice-lib-don-not-set-loaded-state-until-seat-fetched.patch.
  + accountsservice-read-root-user-cache.patch
* Mon Dec 10 2018 xwang@suse.com
- Add accountsservice-read-root-user-cache.patch: Read root user
  cache file (bsc#1114292 glfo#accountsservice/accountsservice#65).
* Sun Jul 22 2018 bjorn.lie@gmail.com
- Update to version 0.6.50:
  + Fix insufficient path check on user icon files. (bsc#1099699
    CVE-2018-14036)
  + Fix is-logged-in status for wayland sessions.
  + Fix user enumeration when system accounts are mixed in.
- Drop upstream fixed patches:
  + accountsservice-missing-users-on-gdm-login.patch.
  + accountsservice-lib-treat-session-type-wayland-as-graphical-session.patch
* Fri Jul 20 2018 qkzhu@suse.com
- Add accountsservice-lib-don-not-set-loaded-state-until-seat-fetched.patch:
  At the moment we set is-loaded on the user-manager object as soon
  as we start fetching the seat, but we should waiting until the seat
  is fetched, so that can_switch() will return the correct value if
  the caller waited until the loaded signal to use it.
  (boo#1100041 fdo#107298)
* Tue Jul 17 2018 xwang@suse.com
- Add accountsservice-lib-treat-session-type-wayland-as-graphical-session.patch:
  When user session type is wayland, act_user_is_logged_in can
  return TRUE if the user is logged in (boo#1095918 fdo#106855).
* Wed Jul 11 2018 mliska@suse.cz
- Make build verbose to see full command lines.
* Wed Jun 13 2018 fezhang@suse.com
- Add accountsservice-missing-users-on-gdm-login.patch: Don't abort
  loading users when an /etc/shadow entry found missing
  (boo#1090003 fdo#106904).
* Sun May 13 2018 luc14n0@linuxmail.org
- Update to version 0.6.49:
  + Fix crash on startup from previous compiler warning fix.
- Changes from version 0.6.48:
  + Fix crashes when adding admin user and when user is removed.
  + Performance improvements handling really large wtmp files.
- Changes from version 0.6.47:
  + Fix problem where libaccountsservice users weren't getting
    property change updates.
  + Reduce memory usage of cached users in daemon process.
  + Drop premature user-added/user-removed signals that erroneously
    get emitted before ListCachedUsers call finishes.
* Fri Apr  6 2018 luc14n0@linuxmail.org
- Update to version 0.6.46:
  + Fix systemd unit file to use default standard output;
  + Performance improvements;
  + Leak fixes;
  + Crash fixes;
  + Support extra groups for admin users;
  + Add policy that allows admins to allow users to change their
    own password;
  + Introspection fixes;
  + Elogind support;
  + Decruftification of username blacklist;
  + Updated translations.
- Add:
  + gio-2.0 and gio-unix-2.0 pkgconfig modules BuildRequires to
    avoid implicit dependencies.
  + xmlto and xsltproc BuildRequires to enable documentation.
- Drop remove-no-longer-used-system-accounts.patch: fixed upstream.
- Rebase patches:
  + accountsservice-sysconfig.patch and
  + accountsservice-filter-suse-accounts.patch.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Dec 22 2017 qzheng@suse.com
- Add remove-no-longer-used-system-accounts.patch:
  Drop operator, nobody4 and noaccess from the blacklist
  (bsc#1063794, fdo#103879).
* Thu Aug 10 2017 yfjiang@suse.com
- Update specfile to build
  as-fate318433-prevent-same-account-multi-logins.patch on SLE15.
* Tue Jul  4 2017 jengelh@inai.de
- Remove redundant %%clean section; use %%_smp_mflags for build.
* Tue Apr 25 2017 dimstar@opensuse.org
- Update to version 0.6.45:
  + Wrap password expiration info in libaccountsservice api.
- Changes from version 0.6.44:
  + Export password expiration info from shadow file.
  + Fix user classification logic.
  + Don't lose track of users when /etc/passwd is reloaded.
- Drop accountsservice-933083-load-root-setting.patch:
  fixed upstream (177509 edac45).
* Wed Nov 30 2016 dimstar@opensuse.org
- Rebase accountsservice-933083-load-root-setting.patch.
* Sat Sep 24 2016 zaitor@opensuse.org
- Update to version 0.6.43:
  + Fix logout times in login-history.
  + Increase performance in large deployments.
  + Memory leak fix.
  + Exclude nologin users from user list.
* Sun Sep 11 2016 fezhang@suse.com
- Update accountsservice-sysconfig.patch:
  Flush the buffer before shut down the GIOChannel, otherwise we
  get a truncated setting file. The problem has caused the
  switching autologin in gnome-control-center breaking
  /etc/sysconfig/displaymanager (bsc#998107).
* Wed Aug 24 2016 fezhang@suse.com
- Enable as-fate318433-prevent-same-account-multi-logins.patch for
  Leap as requested by the Leap Release Manager (boo#994876).
* Wed Jul  6 2016 fbui@suse.com
- Remove pkgconfig(libsystemd-daemon). Nowadays
  pkgconfig(libsystemd) is enough and replaces all libsystemd-*
  libs which are obsolete.
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 0.6.42:
  + Wtmp fixes on solaris.
  + Allow a user to change his own data even if he's remote.
  + Add way to set password hint independent of password.
  + Conform to modern systemd library naming scheme.
  + Disable GVFS support in service, since it's not needed and has
    bad side effects.
- Replace pkgconfig(libsystemd-login) for pkgconfig(libsystemd)
  BuildRequires following upstream changes.
* Sat May 28 2016 cxiong@suse.com
- Add as-fate318433-prevent-same-account-multi-logins.patch
  (fate#318433):
  Prevent multiple simultaneous logins.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Rebased accountsservice-933083-load-root-setting.patch.
* Mon Jan 11 2016 michael@stroeder.com
- Updated Url.
* Thu Jun  4 2015 dliang@suse.com
- Add accountsservice-933083-load-root-setting.patch (bnc#933083)
  Load settings of an account which is not 'human' but can still be
  able to login to the system. (like 'root')
* Tue Jan 27 2015 zaitor@opensuse.org
- Update to version 0.6.40:
  + Support large UIDs better.
  + Don't require X11 display to fetch user with X11 session.
  + Ensure accountsservice doesn't start before NSS works.
* Sun Oct 19 2014 zaitor@opensuse.org
- Update to version 0.6.39:
  + Fix ListCachedUsers race at startup.
  + Add new api for uncaching user.
  + Fix memory corruption bug.
  + Build goo changes.
* Sun Oct  5 2014 zaitor@opensuse.org
- Pass --enable-user-heuristics to configure to ensure that legacy
  users are still shown in GDM facebrowser.
* Thu Sep 25 2014 dimstar@opensuse.org
- Update to version 0.6.38:
  + Fix polkit policy for non-desktop cases.
  + Fix for a race when new user appears.
  + Some clearer log and debug messages.
* Wed Apr  2 2014 dimstar@opensuse.org
- Update to version 0.6.37:
  + BSD fixes.
- Changes from version 0.6.36:
  + Fixes for deleting users.
  + Leak fix.
  + Change user classification logic.
  + BSD fixes.
- Rebase accountsservice-sysconfig.patch and
  accountsservice-filter-suse-accounts.patch.
* Wed Oct 16 2013 dimstar@opensuse.org
- Update to version 0.6.35:
  + Handle non-existent users better.
  + Misc bug fixes.
  + Misc clean ups.
  + Emit "changed" signal when account type changes for user.
  + Stop shipping vapi files.
  + Avoid connecting to ConsoleKit on logind systems.
  + Add extension interface.
  + Add --enable-coverage option for gcov support.
- Rebase accountsservice-sysconfig.patch and
  accountsservice-filter-suse-accounts.patch.
- Drop accountsservice-remotePW-verification.patch: fixed upstream.
* Wed Oct  9 2013 dimstar@opensuse.org
- Add accountsservice-remotePW-verification.patch: treat NULL
  shadow entry as "password handled remotely" (bnc#844933,
  bgo#708997, fdo#70005).
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 0.6.34:
  + Try to sanitize automatic login setting when user account is
    deleted or disabled (fdo#54506).
  + Fix build.
- Changes from version 0.6.33:
  + Keep track of non-graphical sessions (fdo#65160).
  + Forget obsolete sessions (fdo#65159).
  + Monitor wtmp for changes (fdo#63159).
  + Ignore non-user sessions (fdo#701514).
  + Rework system account handling (fdo#64769).
  - Never treat cached users as system accounts.
  - Add gdm, gnome-initial-setup users to blacklist.
  - Store system-account bit in key file.
  - Cache newly-created users explicitly.
- Rebase accountsservice-filter-suse-accounts.patch.
* Wed May 15 2013 dimstar@opensuse.org
- Update to version 0.6.32:
  + Don't treat remote users as system accounts (fdo#64186).
  + Clean up spawn_with_login_uid error handling (fdo#55067).
  + Quit on SIGINT/SIGTERM (fdo#63869).
  + Make --debug work as expected (fdo#63870).
  + Remove newlines from debug output (fdo#63871).
  + Fix mismatched function signature (fdo#63873).
  + Fix gir/vapi warnings (fdo#63875).
  + Fix documentation warnings (fdo#63880).
* Wed Apr 17 2013 dimstar@opensuse.org
- Update to version 0.6.31:
  + Check for logind, not systemd (bgo#62586).
  + Add --enable-admin-group configure option (bgo#62235).
  + Be more aggressive at excluding system accounts (bgo#48178).
  + Fix xsession property notification (bgo#58493).
  + Fix login history variant handling (bgo#58466).
- Rebase accountsservice-sysconfig.patch.
* Sun Dec 16 2012 dimstar@opensuse.org
- Update to version 0.6.30:
  + Minor source clean ups.
  + Crasher fix on 32bit systems.
  + Add get_user_by_id.
  + Don't lose sessions list for users at startup.
  + Add API for detecting when accountsservice is unavailable.
* Fri Nov 23 2012 dimstar@opensuse.org
- Update to version 0.6.29:
  + Translate D-Bus errors to local errors in libaccountsservice.
  + Fix a wrong property name in the login history support.
* Mon Nov 19 2012 dimstar@opensuse.org
- Update to version 0.6.28:
  + Fix act_user_manager_delete_user_finish.
  + Fix handling of LoginTime and LoginHistory properties.
- Changes from version 0.6.27:
  + Fix warnings when the singleton user manager object is
    finalized.
  + Generated docs for libaccountsservice.
  + Initialize local_acount to TRUE.
  + Add async api for user creation, caching and deletion.
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 0.6.26:
  + Require libsystemd-login 186.
  + Protect against deleting root user.
  + Add LoginTime and LoginHistory properties.
  + Fix crash consolekit code.
  + Fix has_multiple_user property after removing user.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 0.6.25:
  + Uninitialized variable fix
  + Typo fix
  + Create data dirs just-in-time
  + Ignore closing sessions for is_logged_in test
  + Disable NULL user for delete_user call
  + Updated translations.
* Tue Aug 28 2012 dimstar@opensuse.org
- Update to version 0.6.24:
  + add User.Local property for identifying local users.
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 0.6.23:
  + Fix up some debug output.
  + add new CacheUser and UncacheUser apis.
  + uncache user before deleting user.
* Wed Jul 18 2012 dimstar@opensuse.org
- Add the user 'fax' to the exception list (bnc#771177).
* Thu Jun 28 2012 dimstar@opensuse.org
- Update to version 0.6.22:
  + Correct CVE-2012-2737, local file disclosure
  + small memory leak fix
  + exclude system accounts from ListCachedUsers
  + make has-multiple-users properly only check non-system users
  + remove icon when deleting user
  + Revert usage of getpwent() as fallback for fgetpwent
  + support consolekit call cancellation to prevent crashes caused
    by shortlived sessions
  + ignore built files in .gitignore
  + quiet down build goo nagging
- Drop accountsservice-CVE-2012-2737.patch: fixed upstream.
* Wed Jun 27 2012 vuntz@opensuse.org
- Add accountsservice-CVE-2012-2737.patch: fix local file
  disclosure flaw. Fix bnc#768807, CVE-2012-2737.
* Tue Jun 26 2012 dimstar@opensuse.org
- Add users cyrus, ldap and mailman to the openSUSE specific users
  to be excluded (accountsservice-filter-suse-accounts.patch).
  Fixes bnc#765487.
* Fri May 18 2012 dimstar@opensuse.org
- Update to version 0.6.21:
  + Detect old versions of systemd and fall back to ConsoleKit
  + Exclude users without a valid shell
  + Fix log spew
* Fri May  4 2012 dimstar@opensuse.org
- Update to version 0.6.20:
  + Fix user listing which broke in previous release
- Changes from version 0.6.19:
  + Fix spurious warnings in logs
  + Make userdel succeed even if user is already logged in
  + Exclude users with no shell
  + Exclude "at" user
- Drop accountsservice-filter-more-accounts.patch and
  accountsservice-filter-no-shell.patch: fixed upstream.
* Mon Apr 23 2012 vuntz@opensuse.org
- Add back accountsservice-filter-more-accounts.patch to filter the
  at user.
- Add accountsservice-filter-no-shell.patch to filter users with no
  shell, which happens when NIS is setup.
- This should fix bnc#757662.
- Rebase accountsservice-filter-suse-accounts.patch.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 0.6.18:
  + Fix systemd configure check
  + Add a few more common system accounts to the blacklist
  + Fix some issues in systemd session handling
- Drop accountsservice-filter-more-accounts.patch: fixed upstream.
- Drop accountsservice-fix-systemd-test-always-evaluating-true.patch:
  fixed upstream.
* Tue Apr  3 2012 vuntz@opensuse.org
- Add accountsservice-filter-more-accounts.patch: filter out ftp,
  games, man and mysql system users too, taken from git.
- Add accountsservice-filter-suse-accounts.patch: filter out some
  openSUSE-specific accounts (beagleindex, suse-ncc).
* Mon Apr  2 2012 zaitor@opensuse.org
- Add accountsservice-fix-systemd-test-always-evaluating-true.patch
  Make it possible to build accountsservice without systemd
  (fdo#48190).
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 0.6.17:
  + Fix user filtering which was broken in 0.6.16
  + Fix double free in user code
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 0.6.16:
  + Don't filter out users below UID_MIN in login.defs
  + Filter out users with invalid shells
  + Use infinite timeout for ListCachedUsers calls
  + Port to GDBus
  + Add systemd support
  + Build fixes for srcdir != builddir
  + Vala support and introspection fixes
  + PPC32 fixes
  + Updated translations.
- Drop pkgconfig(dbus-glib-1) BuildRequires: dependency is gone
  upstream.
- Enable support for systemd session tracking:
  + Note that it will fall back to ConsoleKit at runtime, so it's
    fine to build it.
  + Add pkgconfig() BuildRequires: libsystemd-login,
    libsystemd-daemon.
- Rebase accountsservice-sysconfig.patch.
- Add vala BuildRequires, which is now needed because of the
  gnome-autogen.sh call.
* Mon Feb 27 2012 vuntz@opensuse.org
- Fix systemd-related packaging:
  + Use %%{?systemd_requires}.
  + Call %%service_{add,del}_* macros in scriptlets for
    accounts-daemon.service.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-AccountsService-1_0
  subpackage.
- Add typelib-1_0-AccountsService-1_0 Requires to devel subpackage.
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 0.6.15:
  + Only accept regular files as icons
  + Don't track non-graphical sessions
  + Fix wtmp handling
  + Fix build on FreeBSD and OpenBSD
- Drop accountsservice-regular-file-for-icon.patch: fixed upstream.
* Thu Sep 29 2011 vuntz@opensuse.org
- Add accountsservice-regular-file-for-icon.patch: only use regular
  files when setting user icon. Part of bnc#676638.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 0.6.14:
  + Ignore extraneous SetAutomaticLogin(false) calls for a user
  + Monitor /etc/gdm/custom.conf for changes in autologin config
  + Fix fast user switching
  + Fix docs to build
  + Updated translations.
- Rebase accountsservice-sysconfig.patch, and add gnome-common
  BuildRequires and call to gnome-autogen.sh since it's easier to
  rebase the patch without Makefile.in.
- Add gobject-introspection-devel BuildRequires to build
  introspection data.
* Wed Jul 20 2011 vuntz@opensuse.org
- Add accountsservice-sysconfig.patch: read and write autologin
  configuration from sysconfig, as done in gdm. Fix bnc#688071.
* Wed Jul 20 2011 vuntz@opensuse.org
- Update to version 0.6.13:
  + Honor aclocal flags environment variable
  + Set log domain so it can be hushed
  + Use wtmp instead of consolekit for determining login frequency
  + Leak and warning fixes
  + Clean up polkit deprecation warnings
  + Add '--' before username to account helper programs
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Thu May 19 2011 dimstar@opensuse.org
- Update to version 0.6.12:
  + The usual pile of race fixes
- Changes from version 0.6.11:
  + Add API for adding users to the library.
* Mon May  2 2011 vuntz@opensuse.org
- Drop rpmlintrc as the necessary changes have now been done in
  both rpmlint (for suse-dbus-unauthorized-service) and in
  polkit-default-privs (for polkit-unauthorized-privilege).
* Fri Apr 29 2011 fcrozat@novell.com
- Update to version 0.6.10:
  + An assortment of race fixes
  + Updated translations
- Changes from version 0.6.9:
  + Add a 'system-account' property to users
- Update download url for tarball.
* Mon Apr 11 2011 fcrozat@novell.com
- Add pkgconfig(systemd) to BuildRequires and package systemd
  configuration file for accountsservice.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 0.6.8:
  + use same rules for parsing booleans from gdm config as gdm.
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 0.6.7:
  + Fix call to useradd for normal users
  + Correct free array of groups
  + Updated translations
- Changes from version 0.6.6:
  + Make it possible to disable user icon
  + Drop Supervised user role
  + Use "wheel" instead of "desktop_admin_r" as admin group
    since that's what everyone uses for this purpose anyway.
  + Crasher fixes
  + Misc distro integration fixes
  + Updated translations
- Changes from version 0.6.5:
  + No longer return excluded users from cached listings
  + Add a --debug command line option
  + Use proper dbus proxy for settings api in client lib
  + Expose XSession property over bus
- Enforce dependency on main package in library package by changing
  Recommends to Requires.
- Add a rpmlintrc to ignore security-related rpmlint warnings that
  make the build fail on Factory. This needs to get removed when
  entering Factory, though.
* Thu Mar  3 2011 vuntz@opensuse.org
- Cleanup for inclusion in Factory.
* Thu Feb 17 2011 fcrozat@novell.com
- Update to version 0.6.4:
  - fix typo in HomeDirectory property
  - fix bug in asynchronous loading code
  - drop some random g_print's
- Changes from version 0.6.3:
  + Add more getters to client library
  + Add an initial cut at a setter api
  + Add XSession property type
- Changes from version 0.6.2:
  + Remove the unused UserChanged signal
  + Add a small client library, based on code from gdm
  + Don't use gnome-common
  + Use the user-administration privilege for autologin changes
- Changes from version 0.6.1:
  + Always emit the changed signal when setting user photo
  + Install systemd unit files
  + Translation updates
- Changes from version 0.6:
  + Always require user-administration privilege when setting a
    password or changing a username
  + Allow changing password mode and password even when the
    account is locked, and unlock it as a side-effect
  + Use /etc/shadow to store account locking and 'set password at
    next login' information and monitor /etc/shadow for changes
  + Set loginuid when runing commands on behalf of a user to
    generate proper audit records
  + Drop SetIconData and make SetIconFile copy the file when
    appropriate.  As a consequence, the service no longer links
    against image libraries.
  + Various other robustness and error-handling fixes
- Changes from version 0.5:
  + Make initial user list call work
  + Avoid extraneous commandline parsing
- Package directories used by daemon to store user data:
  /var/lib/AccountsService and subdirectories.
* Sat Jan 30 2010 captain.magnus@opensuse.org
- New package (version 0.4).
